==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/PropertyPages/kpgprimarykeyproppage.h <==
//
// C++ Interface: kpgprimarykeyproppage
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGPRIMARYKEYPROPPAGE_H
#define KPGPRIMARYKEYPROPPAGE_H

#include "kpgprimarykeyproppagebase.h"

// application specific includes
#include "kpgabstractpropertypage.h"

// include files for libpgxx 
#include <pqxx/util.h> 

class KPGSyntaxHighlighter;
class KPGPrimaryKey;

/**
Primary key properties

@author Lumir Vanek
*/

class KPGPrimaryKeyPropPage : public KPGPrimaryKeyPropPageBase, public KPGAbstractPropertyPage
{
	Q_OBJECT
public:
    KPGPrimaryKeyPropPage(QWidget *parent, KPGPrimaryKey *);
    ~KPGPrimaryKeyPropPage();
	
	// Return Result table for clipboard actions and export. 
	virtual QTable* tableResult() { return m_pTableProperties; }
	
protected slots:

    /**
     * Changes syntax highlighting colors.
     */
    void slotSqlEditorSettingsChanged();

    virtual void slotTablePropDblClicked(int, int, int, const QPoint &);  
                    
	// Consumes request for context menu for property table
	virtual void slotTablePropContextMenuRequested(int, int, const QPoint &);    
	
    virtual void slotRefreshStatistics();
    
signals:
    void sigSearchObject(const pqxx::oid);
                
    // Emit request for context menu for property table
	void sigTablePropContextMenuRequested(int, int, const QPoint &);
	    
protected:
	/** Syntax highlighter for index definition */
	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
	KPGPrimaryKey *m_pIndex;
};

#endif

==> kpogre-1.6.6.tar.gz: kpogre-1.6.6/kpogre/PropertyPages/kpgprimarykeyproppage.h <==
//
// C++ Interface: kpgprimarykeyproppage
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGPRIMARYKEYPROPPAGE_H
#define KPGPRIMARYKEYPROPPAGE_H

#include "kpgprimarykeyproppagebase.h"

// application specific includes
#include "kpgabstractpropertypage.h"

// include files for libpgxx 
#include <pqxx/util> 

class KPGSyntaxHighlighter;
class KPGPrimaryKey;

/**
  * Primary key index properties
  *
  * @author Lumir Vanek
  */
class KPGPrimaryKeyPropPage : public KPGPrimaryKeyPropPageBase, public KPGAbstractPropertyPage
{
	Q_OBJECT
public:
    KPGPrimaryKeyPropPage(QWidget *parent, KPGPrimaryKey *);
    ~KPGPrimaryKeyPropPage();
	
	// Display properties of underlying database object
	virtual void displayProperties();
	void displayStatistics();
    void displayIoStatistics();
    
	// Return Result table for clipboard actions and export. 
	virtual QTable* tableResult() { return m_pTableProperties; }
	
protected slots:

    /**
     * Changes syntax highlighting colors.
     */
    void slotSqlEditorSettingsChanged();

    virtual void slotTablePropDblClicked(int, int, int, const QPoint &);  
                    
	// Consumes request for context menu for property table
	virtual void slotTablePropContextMenuRequested(int, int, const QPoint &);    
	
    virtual void slotRefreshStatistics();
    
signals:
    void sigSearchObject(const pqxx::oid);
                
    // Emit request for context menu for property table
	void sigTablePropContextMenuRequested(int, int, const QPoint &);
	    
protected:
	/** Syntax highlighter for index definition */
	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
	KPGPrimaryKey *m_pIndex;
};

#endif
